@@ -1,11 +1,13 @@
 package Sys::Cmd;
 use strict;
 use warnings;
-our $VERSION = '0.99.1_2';
+our $VERSION = '0.99.1_3';
 use 5.006;
 no warnings "experimental::lexical_subs";
 use feature 'lexical_subs';
-use Carp ();
+use Carp           ();
+use Encode::Locale ();    # Creates the 'locale' alias
+use Encode 'resolve_alias';
 use Exporter::Tidy _map => {
     run      => sub { run( undef, @_ ) },
     spawn    => sub { spawn( undef, @_ ) },
@@ -13,7 +15,7 @@ use Exporter::Tidy _map => {
     runsub   => sub { syscmd( undef, @_ )->runsub },
     spawnsub => sub { syscmd( undef, @_ )->spawnsub },
 };
-### START Class::Inline ### v0.0.1 Tue Mar 25 12:49:25 2025
+### START Class::Inline ### v0.0.1 Thu Mar 27 20:28:54 2025
 require Carp;
 our ( @_CLASS, $_FIELDS, %_NEW );
 
@@ -61,6 +63,10 @@ sub _NEW {
     $_[0]{'dir'} = eval { $_FIELDS->{'dir'}->{'isa'}->( $_[0]{'dir'} ) }
       if exists $_[0]{'dir'};
     Carp::confess( 'Sys::Cmd dir: ' . $@ ) if $@;
+    $_[0]{'encoding'} =
+      eval { $_FIELDS->{'encoding'}->{'isa'}->( $_[0]{'encoding'} ) }
+      if exists $_[0]{'encoding'};
+    Carp::confess( 'Sys::Cmd encoding: ' . $@ ) if $@;
     $_[0]{'env'} = eval { $_FIELDS->{'env'}->{'isa'}->( $_[0]{'env'} ) }
       if exists $_[0]{'env'};
     Carp::confess( 'Sys::Cmd env: ' . $@ ) if $@;
@@ -80,7 +86,11 @@ sub dir { __RO() if @_ > 1; $_[0]{'dir'} // undef }
 
 sub encoding {
     __RO() if @_ > 1;
-    $_[0]{'encoding'} //= $_FIELDS->{'encoding'}->{'default'}->( $_[0] );
+    $_[0]{'encoding'} //= eval {
+        $_FIELDS->{'encoding'}->{'isa'}->( $_FIELDS->{'encoding'}->{'default'} );
+    };
+    Carp::confess( 'invalid (Sys::Cmd::encoding) default: ' . $@ ) if $@;
+    $_[0]{'encoding'};
 }
 sub env   { __RO() if @_ > 1; $_[0]{'env'}   // undef }
 sub err   { __RO() if @_ > 1; $_[0]{'err'}   // undef }
@@ -120,7 +130,7 @@ sub _dump {
     warn "$self $x at $list[1]:$list[2]\n";
 }
 
-@_CLASS =            ### END Class::Inline ###
+@_CLASS = grep 1,### END Class::Inline ###
  {
     cmd => {
         isa => sub {
@@ -133,8 +143,15 @@ sub _dump {
         },
         required => 1,
     },
-    encoding => { default => sub { ':utf8' }, },
-    env      => {
+    encoding => {
+        default => 'locale',
+        isa     => sub {
+            my $e = resolve_alias( $_[0] )
+              || _croak("Unknown Encoding: $_[0]");
+            $e;
+        },
+    },
+    env => {
         isa => sub {
             ref $_[0] eq 'HASH' || _croak("env must be HASHREF");
             $_[0];
@@ -288,11 +305,12 @@ sub spawnsub {
 }
 
 package Sys::Cmd::Process;
-our $VERSION = '0.99.1_2';
+our $VERSION = '0.99.1_3';
 use parent -norequire, 'Sys::Cmd';
+use Encode 'encode';
 use IO::Handle;
 use Log::Any qw/$log/;
-### START Class::Inline ### v0.0.1 Tue Mar 25 12:49:25 2025
+### START Class::Inline ### v0.0.1 Thu Mar 27 20:28:54 2025
 require Carp;
 our ( @_CLASS, $_FIELDS, %_NEW );
 
@@ -401,7 +419,7 @@ sub _dump {
     warn "$self $x at $list[1]:$list[2]\n";
 }
 
-@_CLASS =            ### END Class::Inline ###
+@_CLASS = grep 1,### END Class::Inline ###
  {
     _coderef => {
         default => sub {
@@ -482,8 +500,9 @@ sub _spawn {
       for $old_fd0, $old_fd1, $old_fd2, $child_in, $child_out, $child_err,
       $self->stdin, $self->stdout, $self->stderr;
 
+    my $locale = $self->encoding;
     my $cmd_as_octets =
-      [ map { my $s = $_; utf8::is_utf8($s) ? utf8::encode($s) || $s : $s }
+      [ map { encode( $locale => $_, Encode::FB_CROAK | Encode::LEAVE_SRC ) }
           @{ $self->cmd } ];
 
     eval {
@@ -503,6 +522,7 @@ sub _spawn {
                 ]
             )
         );
+
     };
     my $err = $@;
 
@@ -546,12 +566,12 @@ sub _fork {
     $self->exit(0);            # stop DESTROY() from trying to reap
     $child_err->autoflush(1);
 
-    my $enc = $self->encoding;
+    my $enc = ':encoding(' . $self->encoding . ')';
 
     foreach my $quad (
-        [ \*STDIN,  '<&=' . $enc, fileno($child_in),  0 ],
-        [ \*STDOUT, '>&=' . $enc, fileno($child_out), 1 ],
-        [ \*STDERR, '>&=' . $enc, fileno($child_err), 1 ]
+        [ \*STDIN,  '<&=', fileno($child_in),  0 ],
+        [ \*STDOUT, '>&=', fileno($child_out), 1 ],
+        [ \*STDERR, '>&=', fileno($child_err), 1 ]
       )
     {
         my ( $fh, $mode, $fileno, $autoflush ) = @$quad;
@@ -560,6 +580,7 @@ sub _fork {
           or print $child_err sprintf "[%d] open %s, %s: %s\n", $self->pid,
           $fh, $mode, $!;
 
+        binmode $fh, $enc;
         $fh->autoflush(1) if $autoflush;
     }
 
@@ -612,12 +633,14 @@ sub BUILD {
     local %ENV = %ENV;
 
     if ( defined( my $x = $self->env ) ) {
+        my $locale = $self->encoding;
         while ( my ( $key, $val ) = each %$x ) {
+            my $keybytes = encode( $locale, $key, Encode::FB_CROAK );
             if ( defined $val ) {
-                $ENV{$key} = $val;
+                $ENV{$keybytes} = encode( $locale, $val, Encode::FB_CROAK );
             }
             else {
-                delete $ENV{$key};
+                delete $ENV{$keybytes};
             }
         }
     }
@@ -625,7 +648,7 @@ sub BUILD {
     $self->_coderef ? $self->_fork : $self->_spawn;
     $self->stdin->autoflush(1);
 
-    my $enc = $self->encoding;
+    my $enc = ':encoding(' . $self->encoding . ')';
     binmode( $self->stdin,  $enc ) or warn "binmode stdin: $!";
     binmode( $self->stdout, $enc ) or warn "binmode stdout: $!";
     binmode( $self->stderr, $enc ) or warn "binmode stderr: $!";
@@ -670,8 +693,7 @@ sub close {
 
 sub wait_child {
     my $self = shift;
-
-    return unless defined $self->pid;
+    my $pid  = $self->pid // return;
     return $self->exit if $self->has_exit;
 
     if ( $self->mock ) {
@@ -680,7 +702,7 @@ sub wait_child {
         $self->signal( $signal // 0 );
         $self->core( $core     // 0 );
     }
-    else {
+    elsif ( $pid > 0 ) {
 
         local $?;
         local $!;
@@ -723,6 +745,13 @@ sub wait_child {
         $self->core( $ret & 128 );
     }
 
+    # $pid <= 0, so... bad execution by spawn
+    else {
+        $self->exit(-1);
+        $self->signal(0);
+        $self->core(0);
+    }
+
     if ( $self->signal != 0 ) {
         $log->infof(
             '[%d] %s [signal: %d core: %d]',
@@ -760,7 +789,7 @@ Sys::Cmd - run a system command or spawn a system processes
 
 =head1 VERSION
 
-0.99.1_2 (2025-03-25)
+0.99.1_3 (2025-03-27)
 
 =head1 SYNOPSIS
 
@@ -794,7 +823,7 @@ Sys::Cmd - run a system command or spawn a system processes
     # Spawn a process for asynchronous interaction
     #  - Caller responsible for exec path, all input & output
     #  - No exception raised on non-zero exit
-    $proc = spawn( @cmd, { encoding => ':encoding(iso-8859-3)' },);
+    $proc = spawn( @cmd, { encoding => 'iso-8859-3' },);
 
     while ( my $line = $proc->stdout->getline ) {
         $proc->stdin->print("thanks\n");
@@ -854,10 +883,11 @@ following configuration keys (=> default):
 The working directory the command will be run in. Note that if C<@cmd>
 is a relative path, it may not be found from the new location.
 
-=item encoding => ':utf8'
+=item encoding => $Encode::Locale::ENCODING_LOCALE
 
-An string value identifying the encoding of the input/output
-file-handles, passed to C<binmode>. Defaults to ':utf8'.
+A string value identifying the encoding that applies to input/output
+file-handles, command arguments, and environment variables.  Defaults
+to the 'locale' alias from L<Encode::Locale>.
 
 =item env
 
